@@ -124,7 +124,7 @@ def plot_gaussian_contour (X, y, mu1, s1, mu2, s2, alpha = 0.4, ax = None):
     
     return plt.gca()
 
-def select_features(X, y, metric, metric_name = '', N = 30):
+def select_features(X, y, metric, metric_name = '', N = 30, feature_names = None):
     '''
     Perform feature selection via a specified metric
 
@@ -137,11 +137,16 @@ def select_features(X, y, metric, metric_name = '', N = 30):
 
     plot_feature_importance(metric, metric_name, row_size = 300)
     idx = np.argsort(metric)[::-1][:N] # idx = np.where(F > 30)[0] # np.where(pval < 0.00001)
-    print('Important feature Number: ', len(idx))
+    
+    if (feature_names):
+        print('Important feature indices: ', idx)
+        print('Important feature names: ', feature_names[idx])
 
     X_M = X[:,idx]
     unsupervised_dimension_reductions(X_M, y, set(y))
 
+    return idx
+
 
 def BER(X ,y, M = 10000, NSigma = 10, show = False, save_fig = ''):
     """
@@ -417,7 +422,7 @@ def IG(X, y, show = False, save_fig = ''):
     mi_sorted_idx = np.argsort(mi)[::-1]
 
     if (X.shape[1] > 50):
-        plt.figure(figsize=(40,5))
+        plt.figure(figsize=(20,3))
     else:
         plt.figure() # use default fig size
 
@@ -474,7 +479,7 @@ def CHISQ(X, y, verbose = False, show = False, save_fig = ''):
     CHI2s, ps = chi2(X_mm_scaled, y)
 
     if (X.shape[1] > 50):
-        plt.figure(figsize=(40,5))
+        plt.figure(figsize=(20,3))
     else:
         plt.figure() # use default fig size
 
@@ -768,7 +773,7 @@ def correlate(X,y, verbose = False, show = False):
         for key in ['correlation.r', 'correlation.r2', 'correlation.rho', 'correlation.tau']:
             v = dct[key]
             if (X.shape[1] > 50):
-                plt.figure(figsize=(40,5))
+                plt.figure(figsize=(20,3))
             else:
                 plt.figure() # use default fig size
             plt.bar(list(range(len(v))),v, facecolor="none", edgecolor = "black", width = 0.3, hatch='/')
